@@ -1,14 +1,11 @@
-from django.db import models
+from bluedot_rest_framework.utils.models import models, AbstractRelationTime
 
 
-class AbstractEventConfiguration(models.Model):
+class AbstractEventConfiguration(AbstractRelationTime):
 
     event_id = models.IntegerField()
     value = models.JSONField()
 
-    created = models.DateTimeField(auto_now_add=True)
-    updated = models.DateTimeField(auto_now=True)
-
     class Meta:
         abstract = True
 
