@@ -38,21 +38,32 @@ class LiveView:
             live_room_id=delete_room_id)
         return Response({'room_id': delete_room_id})
 
+    @action(detail=False, methods=['get'], url_path='live-room-current-time', url_name='live-room-current-time')
+    def live_room_current_time(self, request, *args, **kwargs):
+        event_id = request.query_params.get('event_id', None)
+        queryset = self.model_class.objects.get(pk=event_id)
+        now_time = datetime.now()
+        code = 0
+        if now_time >= queryset.start_time and now_time <= queryset.end_time:
+            code = 1
+        current_time = (now_time - queryset.start_time)
+        return Response({'code': code, 'current_time': current_time})
+
     @action(detail=False, methods=['post'], url_path='live-room-create-vod', url_name='live-room-create-vod')
     def live_room_create_vod(self, request, *args, **kwargs):
         queryset = self.model_class.objects.get(
             pk=request.data.get('event_id', None))
-        print(queryset)
-        start_time = str(queryset.live['create_room_time'])[:19]
+
+        start_time = str(queryset.live_create_room_time)[:19]
         end_time = str(datetime.now())[:19]
         vod = Vhall.create_vod(action='SubmitCreateRecordTasks',
                                app_id='b37675d5',
-                               stream_id=queryset.live['room_id'],
+                               stream_id=queryset.live_room_id,
                                start_time=start_time,
                                end_time=end_time)
         if vod:
             queryset.update(
-                live_playback=1, live_vod_id=vod['vod_id'], live_task_id=vod['task_id'])
+                live_playback=1, live_vod_id=vod['live_vod_id'], live_task_id=vod['live_task_id'])
             return Response({'code': 1})
         return Response({'code': 0})
 
@@ -77,7 +88,6 @@ class LiveView:
             with open(ppt_path, 'wb') as f:
                 data = ppt.read()
                 f.write(data)
-            print('ppt_path', ppt_path)
             image_list = ppt2images(ppt_path, ppt_name, event_id)
             queryset = EventLivePPT.objects.filter(event_id=event_id).first()
             if queryset:
