@@ -8,6 +8,8 @@ class AbstractEventRegister(AbstractRelationUser, AbstractRelationTime):
     source = models.IntegerField(default=0)
     state = models.IntegerField(default=0)
 
+    tel_region = models.CharField(max_length=32, null=True, default='')
+    industry = models.CharField(max_length=100, null=True, default='')
     first_name = models.CharField(max_length=100)
     last_name = models.CharField(max_length=100)
     email = models.CharField(max_length=100)
@@ -23,3 +25,13 @@ class AbstractEventRegister(AbstractRelationUser, AbstractRelationTime):
 class EventRegister(AbstractEventRegister):
     class Meta:
         db_table = 'event_register'
+
+
+class EventRegisterConfig(AbstractRelationTime):
+    event_id = models.CharField(max_length=32)
+    over_time = models.DateTimeField()
+
+    field_list = models.JSONField()
+
+    class Meta:
+        db_table = 'event_register_config'
