@@ -1,5 +1,5 @@
 from datetime import datetime
-from rest_framework.serializers import SerializerMethodField
+from rest_framework.serializers import SerializerMethodField, CharField, IntegerField, DateTimeField, JSONField
 from bluedot_rest_framework.utils.serializers import CustomSerializer
 from bluedot_rest_framework import import_string
 
@@ -8,6 +8,12 @@ Event = import_string('event.models')
 
 class EventSerializer(CustomSerializer):
     time_state = SerializerMethodField()
+    banner = CharField(required=False)
+    description = CharField(required=False)
+    end_time = DateTimeField(required=False)
+    start_time = DateTimeField(required=False)
+    title = CharField(required=False)
+    module_list = JSONField(required=False)
 
     class Meta:
         model = Event
