@@ -14,7 +14,7 @@ EventCommentView = import_string('event.comment.views')
 EventVoteView = import_string('event.vote.views')
 EventVoteUserView = import_string('event.vote.user_views')
 EventVenueView = import_string('event.venue.views')
-
+EventRegisterConfigView = import_string('event.register.config_views')
 
 router = DefaultRouter(trailing_slash=False)
 router.register(r'event/venue', EventVenueView,
@@ -29,6 +29,8 @@ router.register(r'event/question/user', EventQuestionUserView,
                 basename='event-question-user')
 router.register(r'event/chat', EventChatView,
                 basename='event-chat')
+router.register(r'event/register/config', EventRegisterConfigView,
+                basename='event-register-config')
 router.register(r'event/comments', EventCommentView,
                 basename='event-comments')
 router.register(r'event/register', EventRegisterView,
