@@ -10,10 +10,10 @@ class AbstractQuestion(AbstractRelationTime):
 
 
 class AbstractQuestionUser(AbstractRelationUser, AbstractRelationTime):
-    qa_id = models.IntegerField()
+    qa_id = models.IntegerField(null=True)
     title = models.CharField(max_length=100, null=True)
     integral = models.IntegerField(default=0)
-    qa = models.JSONField()
+    qa = models.JSONField(null=True)
 
     class Meta:
         abstract = True
