@@ -40,6 +40,10 @@ DEFAULTS_SETTINGS = {
             'models': 'bluedot_rest_framework.event.register.models.EventRegister',
             'serializers': 'bluedot_rest_framework.event.register.serializers.EventRegisterSerializer',
             'views': 'bluedot_rest_framework.event.register.views.EventRegisterView',
+            'config_models': 'bluedot_rest_framework.event.register.models.EventRegisterConfig',
+            'config_serializers': 'bluedot_rest_framework.event.register.serializers.EventRegisterConfigSerializer',
+            'config_views': 'bluedot_rest_framework.event.register.views.EventRegisterConfigView',
+
         },
         'schedule': {
             'models': 'bluedot_rest_framework.event.schedule.models.EventSchedule',
@@ -80,6 +84,19 @@ DEFAULTS_SETTINGS = {
         'serializers': 'bluedot_rest_framework.user.serializers.UserSerializer',
         'views': 'bluedot_rest_framework.user.views.UserView',
     },
+    'material': {
+        'models': 'bluedot_rest_framework.material.models.Material',
+        'serializers': 'bluedot_rest_framework.material.serializers.MaterialSerializer',
+        'views': 'bluedot_rest_framework.material.views.MaterialView',
+    },
+    'question': {
+        'models': 'bluedot_rest_framework.question.models.Question',
+        'serializers': 'bluedot_rest_framework.question.serializers.QuestionSerializer',
+        'views': 'bluedot_rest_framework.question.views.QuestionView',
+        'user_models': 'bluedot_rest_framework.question.models.QuestionUser',
+        'user_serializers': 'bluedot_rest_framework.question.serializers.QuestionUserSerializer',
+        'user_views': 'bluedot_rest_framework.question.views.QuestionUserView',
+    },
     'category': {
         'models': 'bluedot_rest_framework.category.models.Category',
         'serializers': 'bluedot_rest_framework.category.serializers.CategorySerializer',
