@@ -6,8 +6,8 @@ from bluedot_rest_framework.utils.viewsets import CustomModelViewSet, user_perfo
 from bluedot_rest_framework.utils.jwt_token import jwt_create_token_wechat, jwt_get_userinfo_handler
 
 
-User = import_string('USER.models')
-UserSerializer = import_string('USER.serializers')
+User = import_string('user.models')
+UserSerializer = import_string('user.serializers')
 
 
 class UserView(CustomModelViewSet):
@@ -18,10 +18,8 @@ class UserView(CustomModelViewSet):
         serializer = self.get_serializer(data=request.data)
         serializer.is_valid(raise_exception=True)
         self.perform_create(serializer)
-        user_id, openid, unionid, wechat_id = jwt_get_userinfo_handler(
+        wechat_id, unionid = jwt_get_userinfo_handler(
             self.request.auth)
-        serializer.save(openid=openid, unionid=unionid, wechat_id=wechat_id)
+        serializer.save(unionid=unionid, wechat_id=wechat_id)
         user_data = serializer.data
-        user_data['token'] = jwt_create_token_wechat(
-            openid=user_data['openid'], unionid=user_data['unionid'], userid=user_data['id'], wechat_id=user_data['wechat_id'])
         return Response(user_data, status=status.HTTP_201_CREATED)
