@@ -1,8 +1,7 @@
-from django.db import models
+from bluedot_rest_framework.utils.models import models, AbstractRelationTime
 
 
-class WeChatUser(models.Model):
-    openid = models.CharField(max_length=32)
+class WeChatUser(AbstractRelationTime):
     unionid = models.CharField(max_length=32)
     nick_name = models.CharField(max_length=100)
     gender = models.IntegerField()
@@ -11,10 +10,16 @@ class WeChatUser(models.Model):
     province = models.CharField(max_length=32)
     country = models.CharField(max_length=32)
     avatar_url = models.TextField()
-    subscribe = models.IntegerField(default=0)
-
-    created = models.DateTimeField(auto_now_add=True)
-    updated = models.DateTimeField(auto_now=True)
 
     class Meta:
         db_table = 'wechat_user'
+
+
+class WeChatUserOpenid(AbstractRelationTime):
+    wechat = models.ForeignKey(WeChatUser, on_delete=models.CASCADE)
+    appid = models.CharField(max_length=32)
+    openid = models.CharField(max_length=32)
+    subscribe = models.IntegerField(default=0)
+
+    class Meta:
+        db_table = 'wechat_user_openid'
