@@ -3,6 +3,10 @@ from django.db import models
 
 class WeChatResponseMaterial(models.Model):
     user_name = models.CharField(max_length=32)
+
+    """
+    {1: 文字链接}
+    """
     material_type = models.IntegerField()
     title = models.CharField(max_length=255)
     remark = models.TextField()
@@ -19,9 +23,15 @@ class WeChatResponseMaterial(models.Model):
 class WeChatResponseEvent(models.Model):
     material_id = models.IntegerField()
     user_name = models.CharField(max_length=32)
+
+    """
+    {1: 文本, 2: 参数二维码}
+    """
     event_type = models.IntegerField()
+
     title = models.CharField(max_length=255)
     event_key = models.CharField(max_length=100)
+    qrcode_ticket = models.TextField(null=True, default='')
     text = models.CharField(max_length=255, null=True)
     remark = models.TextField()
     state = models.BooleanField(default=True)
@@ -36,7 +46,7 @@ class WeChatResponseEvent(models.Model):
 class WeChatQrcode(models.Model):
     openid = models.CharField(max_length=32)
     scene_str = models.CharField(max_length=32)
-    ticket = models.TextField()
+    ticket = models.TextField(null=True, default='')
 
     created = models.DateTimeField(auto_now_add=True)
     updated = models.DateTimeField(auto_now=True)
