@@ -1,3 +1,4 @@
+from rest_framework.serializers import CharField
 from bluedot_rest_framework.utils.serializers import CustomSerializer
 from .models import WeChatResponseMaterial, WeChatResponseEvent
 
@@ -11,6 +12,12 @@ class WeChatResponseMaterialSerializer(CustomSerializer):
 
 class WeChatResponseEventSerializer(CustomSerializer):
 
+    event_key = CharField(required=False)
+    qrcode_ticket = CharField(required=False)
+    user_name = CharField(required=False)
+    text = CharField(required=False)
+    remark = CharField(required=False)
+
     class Meta:
         model = WeChatResponseEvent
         fields = '__all__'
