@@ -6,14 +6,12 @@ from django.http import HttpResponse, HttpResponseRedirect
 from rest_framework.views import APIView
 from rest_framework.permissions import IsAuthenticatedOrReadOnly
 from rest_framework.response import Response
-from bluedot_rest_framework import import_string
-from bluedot_rest_framework.utils.jwt_token import jwt_create_token_wechat, jwt_get_wechatid_handler
+from bluedot_rest_framework.utils.jwt_token import jwt_get_wechatid_handler
 
 from . import App, WXBizDataCrypt, official_account_oauth
 from .handle import WeChatUserSet
 from .models import WeChatUser
 from .serializers import WeChatUserSerializer
-User = import_string('user.models')
 
 
 class JSSdk(APIView):
@@ -37,50 +35,37 @@ class JSSdk(APIView):
         })
 
 
-# class Auth(APIView):
-#     permission_classes = [IsAuthenticatedOrReadOnly]
+class Auth(APIView):
+    permission_classes = ()
 
-#     def get(self, request, *args, **kwargs):
-#         code = request.GET.get('code')
-#         session_info = MiniProgram.wxa.code_to_session(code)
-#         user_openid = {'openid': session_info['openid']}
-#         user_obj = UesrModel.objects.filter(**user_openid).first()
-#         if user_obj is None:
-#             user_obj = UesrModel.objects.create(**user_openid)
-#         response = UserSerializer(user_obj).data
-#         unionid = ''
-#         if 'unionid' in response:
-#             unionid = response['unionid']
-#         response['session_key'] = session_info['session_key']
-#         response['token'] = jwt_create_token_wechat(
-#             session_info['openid'], unionid, response['id'])
-#         return Response(response)
+    def get(self, request, *args, **kwargs):
+        appid = request.query_params.get('appid', None)
+        code = request.query_params.get('code', None)
+        session_info = App(appid).wxa.code_to_session(code)
+        if 'unionid' in session_info:
+            session_info['token'] = WeChatUserSet(
+                appid=appid, openid=session_info['openid']).get_token()
+        return Response(session_info)
 
-#     def post(self, request, *args, **kwargs):
-#         auth_data = request.data['data']
-#         auth_user = WXBizDataCrypt(
-#             settings.wechat['miniprogram']['APPID'], auth_data['session_key']
-#         ).decrypt(auth_data['encryptedData'], auth_data['iv'])
-#         user_data = {
-#             'unionid': auth_user['unionId'],
-#             'wechat_profile': {
-#                 'nick_name': auth_user['nickName'],
-#                 'avatar_url': auth_user['avatarUrl'],
-#                 'gender': auth_user['gender'],
-#                 'language': auth_user['language'],
-#                 'city': auth_user['city'],
-#                 'province': auth_user['province'],
-#                 'country': auth_user['country'],
-#             }
-#         }
-
-#         UesrModel.objects.filter(
-#             openid=auth_user['openId']).update(**user_data)
-#         user = UesrModel.objects.get(openid=auth_user['openId'])
-#         user = UserSerializer(user).data
-#         user['token'] = jwt_create_token_wechat(
-#             user['openid'], user['unionid'], user['id'])
-#         return Response(user)
+    def post(self, request, *args, **kwargs):
+        auth_data = request.data['data']
+        appid = request.data['appid']
+        auth_user = WXBizDataCrypt(
+            appid, auth_data['session_key']
+        ).decrypt(auth_data['encryptedData'], auth_data['iv'])
+        user_info = {
+            'openid': auth_user['openId'],
+            'unionid': auth_user['unionId'],
+            'nickname': auth_user['nickName'],
+            'headimgurl': auth_user['avatarUrl'],
+            'sex': auth_user['gender'],
+            'language': auth_user['language'],
+            'city': auth_user['city'],
+            'province': auth_user['province'],
+            'country': auth_user['country'],
+        }
+        token = WeChatUserSet(appid=appid, user_info=user_info).get_token()
+        return Response({'token': token})
 
 
 class OAuth(APIView):
